@@ -20,6 +20,7 @@ import (
 	"fmt"
 	"strings"
 	"testing"
+	"time"
 
 	"github.com/blang/semver/v4"
 	"github.com/spf13/cobra"
@@ -116,9 +117,7 @@ func TestGetKubernetesVersion(t *testing.T) {
 	}
 }
 
-var checkRepoMock = func(v semver.Version, repo string) error {
-	return nil
-}
+var checkRepoMock = func(_ semver.Version, _ string) error { return nil }
 
 func TestMirrorCountry(t *testing.T) {
 	// Set default disk size value in lieu of flag init
@@ -385,6 +384,22 @@ func TestValidateImageRepository(t *testing.T) {
 			imageRepository:      "registry.test.com:6666/google_containers",
 			validImageRepository: "registry.test.com:6666/google_containers",
 		},
+		{
+			imageRepository:      "registry.1test.com:6666/google_containers",
+			validImageRepository: "registry.1test.com:6666/google_containers",
+		},
+		{
+			imageRepository:      "registry.t1est.com:6666/google_containers",
+			validImageRepository: "registry.t1est.com:6666/google_containers",
+		},
+		{
+			imageRepository:      "registry.test1.com:6666/google_containers",
+			validImageRepository: "registry.test1.com:6666/google_containers",
+		},
+		{
+			imageRepository:      "abc.xyz1.example.com",
+			validImageRepository: "abc.xyz1.example.com",
+		},
 	}
 
 	for _, test := range tests {
@@ -396,7 +411,6 @@ func TestValidateImageRepository(t *testing.T) {
 			}
 		})
 	}
-
 }
 
 func TestValidateDiskSize(t *testing.T) {
@@ -737,7 +751,7 @@ func TestValidatePorts(t *testing.T) {
 			if got != nil {
 				gotError = got.Error()
 			}
-			if gotError != test.errorMsg {
+			if !strings.EqualFold(gotError, test.errorMsg) {
 				t.Errorf("validatePorts(ports=%v): got %v, expected %v", test.ports, got, test.errorMsg)
 			}
 		})
@@ -888,3 +902,29 @@ func TestValidateGPUs(t *testing.T) {
 		}
 	}
 }
+
+func TestValidateAutoPause(t *testing.T) {
+	tests := []struct {
+		interval    string
+		shouldError bool
+	}{
+		{"1m0s", false},
+		{"5m", false},
+		{"1s", false},
+		{"0s", true},
+		{"-2m", true},
+	}
+	for _, tc := range tests {
+		input, err := time.ParseDuration(tc.interval)
+		if err != nil {
+			t.Fatalf("test has an invalid input duration of %q", tc.interval)
+		}
+		err = validateAutoPauseInterval(input)
+		if err != nil && !tc.shouldError {
+			t.Errorf("interval of %q failed validation; expected it to pass: %v", input, err)
+		}
+		if err == nil && tc.shouldError {
+			t.Errorf("interval of %q passed validataion; expected it to fail: %v", input, err)
+		}
+	}
+}
