@@ -22,7 +22,10 @@ import (
 	"regexp"
 )
 
-const addonsFile = "pkg/minikube/assets/addons.go"
+const (
+	addonsFile = "pkg/minikube/assets/addons.go"
+	dockerfile = "deploy/kicbase/Dockerfile"
+)
 
 type dependency struct {
 	filePath      string
@@ -33,20 +36,22 @@ var dependencies = map[string]dependency{
 	"buildkit":                {"deploy/iso/minikube-iso/arch/x86_64/package/buildkit-bin/buildkit-bin.mk", `BUILDKIT_BIN_VERSION = (.*)`},
 	"calico":                  {"pkg/minikube/bootstrapper/images/images.go", `calicoVersion = "(.*)"`},
 	"cloud-spanner":           {addonsFile, `cloud-spanner-emulator/emulator:(.*)@`},
-	"cni-plugins":             {"deploy/iso/minikube-iso/arch/x86_64/package/cni-plugins/cni-plugins.mk", `CNI_PLUGINS_VERSION = (.*)`},
+	"cni-plugins":             {"deploy/iso/minikube-iso/arch/x86_64/package/cni-plugins-latest/cni-plugins-latest.mk", `CNI_PLUGINS_LATEST_VERSION = (.*)`},
 	"containerd":              {"deploy/iso/minikube-iso/arch/x86_64/package/containerd-bin/containerd-bin.mk", `CONTAINERD_BIN_VERSION = (.*)`},
-	"cri-dockerd":             {"deploy/kicbase/Dockerfile", `CRI_DOCKERD_VERSION="(.*)"`},
+	"cri-dockerd":             {dockerfile, `CRI_DOCKERD_VERSION="(.*)"`},
 	"cri-o":                   {"deploy/iso/minikube-iso/package/crio-bin/crio-bin.mk", `CRIO_BIN_VERSION = (.*)`},
 	"crictl":                  {"deploy/iso/minikube-iso/arch/x86_64/package/crictl-bin/crictl-bin.mk", `CRICTL_BIN_VERSION = (.*)`},
+	"crun":                    {"deploy/iso/minikube-iso/package/crun-latest/crun-latest.mk", `CRUN_LATEST_VERSION = (.*)`},
 	"docker":                  {"deploy/iso/minikube-iso/arch/x86_64/package/docker-bin/docker-bin.mk", `DOCKER_BIN_VERSION = (.*)`},
 	"flannel":                 {"pkg/minikube/cni/flannel.yaml", `flannel:(.*)`},
 	"gcp-auth":                {addonsFile, `k8s-minikube/gcp-auth-webhook:(.*)@`},
 	"gh":                      {"hack/jenkins/installers/check_install_gh.sh", `GH_VERSION="(.*)"`},
-	"go":                      {"Makefile", `GO_VERSION \?= (.*)`},
+	"go":                      {"Makefile", `\nGO_VERSION \?= (.*)`},
 	"go-github":               {"go.mod", `github\.com\/google\/go-github\/.* (.*)`},
 	"golint":                  {"Makefile", `GOLINT_VERSION \?= (.*)`},
 	"gopogh":                  {"hack/jenkins/installers/check_install_gopogh.sh", `github.com/medyagh/gopogh/cmd/gopogh@(.*)`},
 	"gotestsum":               {"hack/jenkins/installers/check_install_gotestsum.sh", `gotest\.tools/gotestsum@(.*)`},
+	"headlamp":                {addonsFile, `headlamp-k8s/headlamp:(.*)@`},
 	"hugo":                    {"netlify.toml", `HUGO_VERSION = "(.*)"`},
 	"ingress":                 {addonsFile, `ingress-nginx/controller:(.*)@`},
 	"inspektor-gadget":        {addonsFile, `inspektor-gadget/inspektor-gadget:(.*)@`},
@@ -54,12 +59,15 @@ var dependencies = map[string]dependency{
 	"kindnetd":                {"pkg/minikube/bootstrapper/images/images.go", `kindnetd:(.*)"`},
 	"kong":                    {addonsFile, `kong:(.*)@`},
 	"kong-ingress-controller": {addonsFile, `kong/kubernetes-ingress-controller:(.*)@`},
+	"kubectl":                 {addonsFile, `bitnami/kubectl:(.*)@`},
 	"metrics-server":          {addonsFile, `metrics-server/metrics-server:(.*)@`},
 	"nerdctl":                 {"deploy/kicbase/Dockerfile", `NERDCTL_VERSION="(.*)"`},
+	"nerdctld":                {"deploy/kicbase/Dockerfile", `NERDCTLD_VERSION="(.*)"`},
+	"node":                    {"netlify.toml", `NODE_VERSION = "(.*)"`},
 	"nvidia-device-plugin":    {addonsFile, `nvidia/k8s-device-plugin:(.*)@`},
 	"registry":                {addonsFile, `registry:(.*)@`},
 	"runc":                    {"deploy/iso/minikube-iso/package/runc-master/runc-master.mk", `RUNC_MASTER_VERSION = (.*)`},
-	"ubuntu":                  {"deploy/kicbase/Dockerfile", `ubuntu:jammy-(.*)"`},
+	"ubuntu":                  {dockerfile, `ubuntu:jammy-(.*)"`},
 }
 
 func main() {
