@@ -46,8 +46,6 @@ var (
 				// searching for 1.* so it does NOT match "KVM_GO_VERSION ?= $(GO_VERSION:.0=)" in the Makefile
 				`GO_VERSION \?= 1.*`:             `GO_VERSION ?= {{.StableVersion}}`,
 				`GO_K8S_VERSION_PREFIX \?= v1.*`: `GO_K8S_VERSION_PREFIX ?= {{.K8SVersion}}`,
-				// Below line commented out due to https://github.com/kubernetes/minikube/issues/15841
-				// `GO_VERSION=[0-9.]+`:             `GO_VERSION={{.StableVersion}}`,
 			},
 		},
 		"hack/jenkins/installers/check_install_golang.sh": {
@@ -67,7 +65,12 @@ var (
 		},
 		"deploy/addons/auto-pause/Dockerfile": {
 			Replace: map[string]string{
-				`golang:.*`: `golang:{{.StableVersion}}`,
+				`golang:.* AS`: `golang:{{.StableVersion}} AS`,
+			},
+		},
+		"deploy/gvisor/Dockerfile": {
+			Replace: map[string]string{
+				`golang:.* AS`: `golang:{{.StableVersion}} AS`,
 			},
 		},
 	}
