@@ -22,6 +22,7 @@ import (
 	"bytes"
 	"encoding/xml"
 	"fmt"
+	"net"
 	"text/template"
 	"time"
 
@@ -197,6 +198,12 @@ func (d *Driver) createNetwork() error {
 			log.Debugf("failed to find free subnet for private KVM network %s after %d attempts: %v", d.PrivateNetwork, 20, err)
 			return fmt.Errorf("un-retryable: %w", err)
 		}
+
+		// reserve last client ip address for multi-control-plane loadbalancer vip address in ha cluster
+		clientMaxIP := net.ParseIP(subnet.ClientMax)
+		clientMaxIP.To4()[3]--
+		subnet.ClientMax = clientMaxIP.String()
+
 		// create the XML for the private network from our networkTmpl
 		tryNet := kvmNetwork{
 			Name:       d.PrivateNetwork,
@@ -207,12 +214,15 @@ func (d *Driver) createNetwork() error {
 		if err = tmpl.Execute(&networkXML, tryNet); err != nil {
 			return fmt.Errorf("executing private KVM network template: %w", err)
 		}
+		log.Debugf("created network xml: %s", networkXML.String())
+
 		// define the network using our template
 		var network *libvirt.Network
 		network, err = conn.NetworkDefineXML(networkXML.String())
 		if err != nil {
 			return fmt.Errorf("defining private KVM network %s %s from xml %s: %w", d.PrivateNetwork, subnet.CIDR, networkXML.String(), err)
 		}
+
 		// and finally create & start it
 		log.Debugf("trying to create private KVM network %s %s...", d.PrivateNetwork, subnet.CIDR)
 		if err = network.Create(); err == nil {
